"""leetx_parser - Find magnet links for TV show episodes"""

__version__ = '0.1.0'
__author__ = 'Evgeny Lobanov <evgeny1602@gmail.com>'
__all__ = []

import logging
logging.getLogger(__name__).addHandler(logging.NullHandler())